@@ -46,7 +46,7 @@ def check_rcfile():
     """See default.config for rcfileversion values, meanings and
     a description of how to add config variables.
     """
-    rcfileversion = 15
+    rcfileversion = 19
     if cfg.get_int("app/rcfileversion") > rcfileversion:
         cfg.drop_user_config()
         return
@@ -116,6 +116,17 @@ def check_rcfile():
             cfg.set_string("sound/%s_player" % k, v[0])
             cfg.set_string("sound/%s_player_options" % k,
                 " ".join(v[1:]))
+    if cfg.get_int("app/rcfileversion") < 17:
+        v = cfg.get_string("app/frontpage").split("/")
+        if v[0] == u"exercises":
+            cfg.set_string("app/frontpage", 
+                           u"/".join([v[0], u"standard"] + v[1:]))
+    if cfg.get_int("app/rcfileversion") < 18:
+        cfg.del_key("gui/web_browser_as_help_browser")
+    if cfg.get_int("app/rcfileversion") < 19:
+        for ex in ('singinterval', 'melodicinterval'):
+            if cfg.get_int("%s/maximum_number_of_intervals" % ex) == 10:
+                cfg.set_int("%s/maximum_number_of_intervals" % ex, 12)
     cfg.set_int("app/rcfileversion", rcfileversion)
     try:
         a = mpd.notename_to_int(cfg.get_string("user/lowest_pitch"))
@@ -305,75 +316,14 @@ class SolfegeApp(cfg.ConfigUtils):
         solfege.win.box_dict[module].on_start_practise()
         solfege.win.enter_test_mode()
     def handle_href(self, href, display_docfile_set_adj=1):
-        # All generatet docbook documents are in utf-8
         urlobj = utils.Url(href)
         if not urlobj.protocol:
-            if urlobj.filename.endswith(".midi"):
-                if os.path.exists(os.path.join(solfege.win.box_dict['docviewer'].m_htmlwidget.m_document_wd, urlobj.filename)):
-                    midifilename = urlobj.filename
-                elif len(urlobj.filename.split('-')) > 1:
-                    # Filename-nl.midi => Filename.midi
-                    v = urlobj.filename.split('-')
-                    w = v[-1].split('.')
-                    midifilename = "-".join(v[:-1])+"."+w[1]
-                else:
-                    midifilename = urlobj.filename
-
-                soundcard.play_mediafile("midi", os.path.join(
-                    solfege.win.box_dict['docviewer'].m_htmlwidget.m_document_wd,
-                    midifilename))
-            else:
-                solfege.win.display_docfile(urlobj.filename, urlobj.anchor)
-        elif urlobj.protocol == 'solfege':
-            self.handle_solfege_href(urlobj)
-        elif urlobj.protocol == 'http':
+            solfege.win.display_docfile(urlobj.filename, urlobj.anchor)
+        else:
             try:
                 webbrowser.open_new(href)
             except Exception, e:
                 solfege.win.display_error_message2(_("Error opening web browser"), str(e))
-        elif urlobj.protocol == 'mailto':
-            if self.get_string("config/mua"):
-                try:
-                    cmdline = self.get_string("config/mua") % urlobj.href
-                except TypeError:
-                    cmdline = "%s %s" % (self.get_string("config/mua"), urlobj.href)
-                os.system(cmdline)
-            else:
-                gu.dialog_ok(_("You have not selected email program. You can do so in the preferences window."))
-        else:
-            gu.dialog_ok("unknown link type: %s" % urlobj.protocol)
-    def handle_solfege_href(self, urlobj):
-        """
-        This method handles three kins of urls:
-        solfege:practise/lesson_id
-            practise the exercise with the lesson id 'lesson_id'
-        solfege:practise/path/to/lessonfile
-            Practise a specific lessonfile. Relative path:
-                solfege:practise/lesson-files/chord-min-major
-            Absolute path:
-                solfege:practise//home/user/src/solfege/lesson-files/filename
-        """
-        solfege.win.hide_help_on_current()
-        # the Url class does not know anything about lesson ids, but we
-        # assume that lesson_ids don't include the '/' character.
-        if '/' not in urlobj.lessonfile:
-            self.practise_lesson_id(urlobj.lessonfile)#FIXME practise_lessonfile
-            return
-        if urlobj.lessonfile:
-            if not os.path.isfile(urlobj.lessonfile):
-                solfege.win.display_error_message(_("Lessonfile not found:\n%s") % urlobj.lessonfile)
-                return
-        p = lessonfile.LessonfileCommon()
-        p.parse_file(urlobj.lessonfile)
-        self._practise_lessonfile(p.header.lesson_id, urlobj)#FIXME test
-        # This loop changes variables in the lesson file header if they
-        # have set values in the url.
-        for key, val in urlobj.config.iteritems():
-            try:
-                self.m_teachers[p.header.module].m_P.header[key] = eval(val)
-            except SyntaxError:
-                gu.dialog_ok(_("Bad url parameter in link: '%s'.\nTrying to continue anyway.") % ("%s=%s" % (key, val)))
-        solfege.win.box_dict[p.header.module].on_start_practise()
     def create_teacher(self, modulename):
         """
         Create the teacher in 'modulename' and add it to self.m_teachers.
@@ -621,36 +571,4 @@ class SolfegeApp(cfg.ConfigUtils):
                     teacher.m_tonika.get_octave_notename(),
                     (teacher.m_tonika + teacher.m_interval).get_octave_notename())
                 yield ret
-    def load_learning_tree_as_frontpage_data(self, filename):
-        """
-        This function can read the old "learning tree" format datafile and
-        convert it to a front page structure.
-        Load into the .m_frontpage_data variable
-        """
-        data = {}
-        data['collections'] = {}
-        data['columns'] = [[]]
 
-        d = eval(open(filename, "r").read())
-        for k in d['menu']:
-            data['columns'][0].append({'heading': k['name'].replace("_", ""), 'collection-ids': []})
-            for k2 in k['children']:
-                newkey = "%s-%s" % (k['name'].lower().replace(" ", "_"), k2['name'].lower().replace(" ", "_"))
-                assert newkey not in data
-                data['collections'][newkey] = k2
-                data['columns'][0][-1]['collection-ids'].append(newkey)
-                del k2['nametotranslate']
-                k2['name'] = k2['name'].replace("_", "")
-
-        lines = sum(len(x['collection-ids'])+1 for x in data['columns'][0])
-        count = 0
-        for idx, x in enumerate(data['columns'][0]):
-            count += len(x['collection-ids']) + 1
-            if count > lines / 2:
-                if len(data['columns']) == 1:
-                    data['columns'].append([])
-                    for i in range(idx+1, len(data['columns'][0])):
-                        data['columns'][1].append(data['columns'][0][idx+1])
-                        del data['columns'][0][idx+1]
-                    break
-        self.m_frontpage_data = data
