@@ -170,11 +170,10 @@ from solfege import lessonfilegui
 from solfege import abstract
 
 
-from solfege import learningtree
+from solfege import frontpage
 from solfege import fpeditor
 from solfege.trainingsetdlg import TrainingSetDialog
 from solfege.practisesheetdlg import PractiseSheetDialog
-from solfege.helpbrowser import HelpBrowser, DocViewer
 from solfege import filesystem
 from solfege import statistics
 
@@ -299,6 +298,10 @@ class ExerciseView(SelectWinBase):
         self.show_all()
     def _display_data(self, page, display_only_tests=False,
             is_search_result=False):
+        """
+        display_only_tests should be True when we are browsing available tests.
+        This will validate statistics for each lesson and display the test result.
+        """
         if not is_search_result:
             self.m_page = page
         try:
@@ -310,21 +313,21 @@ class ExerciseView(SelectWinBase):
         label = None
         for column in page:
             sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
-            assert isinstance(column, learningtree.Column)
+            assert isinstance(column, frontpage.Column)
             first = True
             vbox = gtk.VBox()
             vbox.set_spacing(gu.hig.SPACE_MEDIUM)
             self.g_hbox.pack_start(vbox, False)
             for sect_id, linklist in enumerate(column):
-                if isinstance(linklist, learningtree.Paragraph):
+                if isinstance(linklist, frontpage.Paragraph):
                     label = gtk.Label(linklist.m_text)
                     label.set_line_wrap(True)
                     label.set_alignment(0.0, 0.5)
                     vbox.pack_start(label, False)
                     continue
-                assert isinstance(linklist, learningtree.LinkList)
+                assert isinstance(linklist, frontpage.LinkList)
                 if (display_only_tests
-                    and not learningtree._TreeCommon.tests_in_sub(linklist)):
+                    and not frontpage._TreeCommon.tests_in_sub(linklist)):
                         continue
                 linkbox = gtk.VBox()
                 vbox.pack_start(linkbox, False)
@@ -333,14 +336,15 @@ class ExerciseView(SelectWinBase):
                 heading.set_use_markup(True)
                 linkbox.pack_start(heading, False)
                 for idx, link in enumerate(linklist):
-                    if isinstance(self, TestsView) and not learningtree._TreeCommon.tests_in_sub(link):
+                    if isinstance(self, TestsView) and not frontpage._TreeCommon.tests_in_sub(link):
                         continue
-                    if isinstance(link, learningtree.Page):
+                    if isinstance(link, frontpage.Page):
                         label = gu.ClickableLabel(_no_xgettext(link.m_name))
                         label.connect('clicked', self.on_page_link_clicked, link)
                     else:
                         assert isinstance(link, unicode), type(link)
-                        solfege.db.validate_stored_statistics(link)
+                        if display_only_tests:
+                            solfege.db.validate_stored_statistics(link)
                         try:
                             labeltxt = lessonfile.infocache.get(link, 'title')
                             label = gu.ClickableLabel(_no_xgettext(labeltxt))
@@ -388,12 +392,12 @@ class ExerciseView(SelectWinBase):
         solfege.app.practise_lessonfile(filename)
     def display_search_result(self, searchfor, result, result_C, display_only_tests=False):
         self._display_data(
-          learningtree.Page(u'',
-            learningtree.Column([
-              learningtree.LinkList(
+          frontpage.Page(u'',
+            frontpage.Column([
+              frontpage.LinkList(
             _("Search results for “%s”:" % self.g_searchentry.get_text()),
               result),
-              learningtree.LinkList(
+              frontpage.LinkList(
             _("C-locale search results for “%s”:" % self.g_searchentry.get_text()),
               result_C),
               ])))
@@ -415,19 +419,19 @@ class ExerciseView(SelectWinBase):
             False: lambda filename: True,
             True: lambda filename: lessonfile.infocache.get(filename, 'test')
         }[C_locale]
-        page = learningtree.Page(listitems=learningtree.Column())
+        page = frontpage.Page(listitems=frontpage.Column())
         cur_topic = None
         # the last topic appended to the page
         last_topic = None 
         found = set()
         for child in self.m_page.iterate_flattened():
-            if isinstance(child, learningtree.LinkList):
+            if isinstance(child, frontpage.LinkList):
                 cur_topic = child
             if isinstance(child, unicode):
                 try:
                     if (match_func(child) and test_filter(child)) and child not in found:
                         if cur_topic != last_topic:
-                            page[0].append(learningtree.LinkList(cur_topic.m_name))
+                            page[0].append(frontpage.LinkList(cur_topic.m_name))
                             last_topic = cur_topic
                         found.add(child)
                         page[0][-1].append(child)
@@ -449,7 +453,7 @@ class FrontPage(ExerciseView):
         page_C = self._search(search_for, True, False)
         page_C.m_name = _('Search untranslated lesson titles')
         if not page_C.is_empty():
-            page[0].append(learningtree.LinkList(_('Too few matches?'),
+            page[0].append(frontpage.LinkList(_('Too few matches?'),
                 listitems=[page_C]))
         self.display_data(page, is_search_result=True)
 
@@ -466,7 +470,7 @@ class TestsView(ExerciseView):
         page_C = self._search(search_for, True, True)
         page_C.m_name = u'Search exercises without translating them'
         if not page_C.is_empty():
-            page[0].append(learningtree.LinkList(_('Too few matches?'),
+            page[0].append(frontpage.LinkList(_('Too few matches?'),
                 listitems=[page_C]))
         self.display_data(page, is_search_result=True)
 
@@ -481,8 +485,8 @@ class SearchView(ExerciseView):
          ]),
         ])
         )"""
-        p = learningtree.parse_tree(page)
-        self.display_data(learningtree.parse_tree(page))
+        p = frontpage.parse_tree(page)
+        self.display_data(frontpage.parse_tree(page))
         self.g_searchentry.show()
     def display_data(self, data):
         self._display_data(data)
@@ -517,7 +521,6 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
         self.connect('delete-event', self.quit_program)
         self.connect('key_press_event', self.on_key_press_event)
         self.g_about_window = None
-        self.g_help_browser = None
         self.m_exercise = None
         self.m_viewer = None
         self.box_dict = {}
@@ -535,7 +538,7 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
         self.main_box = gtk.VBox()
         self.main_box.show()
         self._vbox.pack_start(self.main_box)
-        self.on_learning_tree_changed()
+        self.on_frontpage_changed()
         self.display_frontpage()
     def get_view(self):
         """
@@ -567,13 +570,13 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
         self.m_viewer = name
         self.box_dict[name].show()
         return True
-    def change_learning_tree(self, tree_fn):
+    def change_frontpage(self, filename):
         """
-        Change to a different learning tree.
+        Change to a different frontpage file.
         """
-        self.set_string('app/frontpage', tree_fn)
-        self.on_learning_tree_changed()
-    def on_learning_tree_changed(self, *v):
+        self.set_string('app/frontpage', filename)
+        self.on_frontpage_changed()
+    def on_frontpage_changed(self, *v):
         """
         Load the frontpage data from the file specified by the config
         variable "app/frontpage"
@@ -585,13 +588,13 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
         if not os.path.isfile(filename):
             filename = self.default_front_page
         try:
-            solfege.app.m_frontpage_data = learningtree.load_tree(filename)
+            solfege.app.m_frontpage_data = frontpage.load_tree(filename)
         except Exception, e:
             if splash_win:
                 splash_win.hide()
-            solfege.app.m_frontpage_data = learningtree.load_tree(self.default_front_page)
+            solfege.app.m_frontpage_data = frontpage.load_tree(self.default_front_page)
             self.set_string('app/frontpage', self.default_front_page)
-            gu.dialog_ok(_("Learning front page '%s' failed. Using default page." % filename),
+            gu.dialog_ok(_("Loading front page '%s' failed. Using default page." % filename),
                 secondary_text = "\n".join(traceback.format_exception(*sys.exc_info())))
             if splash_win:
                 splash_win.show()
@@ -608,7 +611,7 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
             lambda o: solfege.app.handle_href('theory-intervals.html')),
           ('TreeEditor', None, _('_Edit Front Page'), None, None,
             self.do_tree_editor),
-          ('ExportTrainingSet', None, _('Training Set E_ditor'), None, None,
+          ('ExportTrainingSet', None, _('E_xport Exercises to Audio Files'), None, None,
             self.new_training_set_editor),
           ('EditPractiseSheet', None, _('Ear Training Test Pri_ntout'), None, None,
             self.new_practisesheet_editor),
@@ -649,18 +652,18 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
         hdlbox.add(self.g_ui_manager.get_widget('/Menubar'))
         self._vbox.pack_start(hdlbox, False)
         self.m_help_on_current_merge_id = None
-    def create_learning_trees_menu(self):
+    def create_frontpage_menu(self):
         """
         Create, or update if already existing, the submenu that let the
         user choose which front page file to display.
         """
-        if self.m_learning_trees_merge_id:
-            self.g_ui_manager.remove_ui(self.m_learning_trees_merge_id)
+        if self.m_frontpage_merge_id:
+            self.g_ui_manager.remove_ui(self.m_frontpage_merge_id)
         actions = []
         old_dir = None
         s = "<menubar name='Menubar'><menu action='FileMenu'><menu action='FrontPagesMenu'>"
-        for fn in learningtree.get_front_pages_list(solfege.app.m_options.debug):
-            if not learningtree.may_be_frontpage(fn):
+        for fn in frontpage.get_front_pages_list(solfege.app.m_options.debug):
+            if not frontpage.may_be_frontpage(fn):
                 continue
             cur_dir = os.path.split(fn)[0]
             if old_dir != cur_dir:
@@ -669,13 +672,13 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
             s += "<menuitem action='%s'/>\n" % fn
             if not self.m_action_groups['NotExit'].get_action(fn):
                 actions.append((fn, None, lessonfile.infocache.frontpage.get(fn, 'title'), None, fn,
-                lambda o, f=fn: self.change_learning_tree(f)))
+                lambda o, f=fn: self.change_frontpage(f)))
             else:
                 action = self.m_action_groups['NotExit'].get_action(fn)
                 action.props.label = lessonfile.infocache.frontpage.get(fn, 'title')
         s += "</menu></menu></menubar>"
         self.m_action_groups['NotExit'].add_actions(actions)
-        self.m_learning_trees_merge_id = self.g_ui_manager.add_ui_from_string(s)
+        self.m_frontpage_merge_id = self.g_ui_manager.add_ui_from_string(s)
     def show_help_on_current(self):
         """
         Show the menu entries for the exercise help and music theory
@@ -796,10 +799,13 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
             box1, box2 = gu.hig_category_vbox(_("File locations"))
             vbox.pack_start(box1)
             sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
+            # statistics.sqlite
+            # win32 solfegerc
+            # win32 langenviron.txt
+            box2.pack_start(gu.hig_label_widget(_("Solfege application data:"), gtk.Label(filesystem.app_data()), sizegroup))
+            box2.pack_start(gu.hig_label_widget(_("Solfege user data:"), gtk.Label(filesystem.user_data()), sizegroup))
             box2.pack_start(gu.hig_label_widget(_("Solfege config file:"), gtk.Label(filesystem.rcfile()), sizegroup))
-            box2.pack_start(gu.hig_label_widget(_("Solfege standard lesson files:"), gtk.Label(os.path.join(os.getcwdu(), "exercises/lesson-files")), sizegroup))
-            box2.pack_start(gu.hig_label_widget(_("The users private lesson files:"), gtk.Label(filesystem.user_lessonfiles()), sizegroup))
-            box2.pack_start(gu.hig_label_widget(_("The users private learning trees:"), gtk.Label(os.path.join(filesystem.user_data(), "learningtrees")), sizegroup))
+            box2.pack_start(gu.hig_label_widget(_("Solfege installation directory:"), gtk.Label(os.getcwdu()), sizegroup))
             box2.pack_start(gu.hig_label_widget(_("User manual in HTML format:"), gtk.Label(os.path.join(os.getcwdu(), "help")), sizegroup))
             self.g_path_info_dlg.show_all()
             def f(*w):
@@ -845,8 +851,8 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
         fpeditor.Editor.edit_file(self.get_string("app/frontpage"))
     def post_constructor(self):
         global splash_win
-        self.m_learning_trees_merge_id = None
-        self.create_learning_trees_menu()
+        self.m_frontpage_merge_id = None
+        self.create_frontpage_menu()
         self.g_ui_manager.add_ui_from_file("help-menu.xml")
         if solfege.app.m_sound_init_exception is not None:
             if splash_win:
@@ -887,7 +893,7 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
             os.path.exists(os.path.join(filesystem.app_data(),
                                         "learningtrees"))):
             if not os.path.exists(os.path.join(filesystem.user_data(), "learningtrees")):
-                os.mkdir(os.path.join(filesystem.user_data(), "learningtrees"))
+                os.makedirs(os.path.join(filesystem.user_data(), "learningtrees"))
             for fn in os.listdir(os.path.join(filesystem.app_data(), "learningtrees")):
                 if not os.path.exists(os.path.join(filesystem.user_data(), "learningtrees", fn)):
                     shutil.move(os.path.join(filesystem.app_data(), "learningtrees", fn),
@@ -898,7 +904,7 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
                             os.path.join(filesystem.user_data(), "learningtrees", u"%s.bak" % fn))
                 os.rmdir(os.path.join(os.path.join(filesystem.app_data(), "learningtrees")))
         item = self.g_ui_manager.get_widget("/Menubar/FileMenu/FrontPagesMenu")
-        item.connect('activate', lambda s: self.create_learning_trees_menu())
+        item.connect('activate', lambda s: self.create_frontpage_menu())
         try:
             i18n.locale_setup_failed
             print >> sys.stderr, "\n".join(textwrap.wrap("Translations are disabled because your locale settings are broken. This is not a bug in GNU Solfege, so don't report it. The README file distributed with the program has some more details."))
@@ -967,30 +973,23 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
         """
         Display the HTML file named by fn in the help browser window.
         """
-        if self.get_bool('gui/web_browser_as_help_browser'):
-            for lang in solfege.app.m_userman_language, "C":
-                filename = os.path.join(os.getcwdu(), u"help", lang, fn)
-                if os.path.isfile(filename):
-                    break
-            try:
-                webbrowser.open(filename)
-            except Exception, e:
-                self.display_error_message2(_("Error opening web browser"), str(e))
-        else:
-            if not self.g_help_browser:
-                self.g_help_browser = HelpBrowser()
-            self.g_help_browser.show()
-            self.g_help_browser.present()
-            self.g_help_browser.show_docfile(fn, anchor)
+        for lang in solfege.app.m_userman_language, "C":
+            filename = os.path.join(os.getcwdu(), u"help", lang, fn)
+            if os.path.isfile(filename):
+                break
+        try:
+            webbrowser.open(filename)
+        except Exception, e:
+            self.display_error_message2(_("Error opening web browser"), str(e))
     def display_user_exercises(self, w):
-        col = learningtree.Column()
-        page = learningtree.Page(_('User exercises'), col)
+        col = frontpage.Column()
+        page = frontpage.Page(_('User exercises'), col)
         curdir =None
         for filename in lessonfile.infocache.iter_user_files():
             dir, fn = os.path.split(filename)
             if dir != curdir:
                 curdir = dir
-                linklist = learningtree.LinkList(dir)
+                linklist = frontpage.LinkList(dir)
                 col.append(linklist)
             linklist.append(filename)
         if os.path.isdir(filesystem.user_lessonfiles()):
@@ -999,16 +998,16 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
             # pre 3.15.3 location:
             for filename in os.listdir(filesystem.user_lessonfiles()):
                 if not linklist:
-                    linklist = learningtree.LinkList(filesystem.user_lessonfiles())
+                    linklist = frontpage.LinkList(filesystem.user_lessonfiles())
                 linklist.append(os.path.join(filesystem.user_lessonfiles(), filename))
             # only display the linklist if there are any files.
             if linklist:
                 col.append(linklist)
         self.display_frontpage(page)
     def display_recent_exercises(self, w):
-        data = learningtree.Page(_('Recent exercises'),
-            [learningtree.Column(
-                [learningtree.LinkList(_('Recent exercises'),
+        data = frontpage.Page(_('Recent exercises'),
+            [frontpage.Column(
+                [frontpage.LinkList(_('Recent exercises'),
                    solfege.db.recent(8))])])
         self.display_frontpage(data)
         self.get_view().g_searchbox.hide()
